Dojo Toolkit - Background Iframe test

This is one tooltip. This is another tooltip. A little longer... This is one tooltip. This is another tooltip. A little longer...

This <select> will disappear on IE6 when the dialog is displayed. But the dialog's iframe shouldn't make it disappear because they shouldn't overlap. Mouse over this to see the tooltip Mouse over this to see a different tooltip |

This select will disappear on IE6 when the dialog is displayed. But the dialog's iframe shouldn't make it disappear because they shouldn't overlap. Mouse over this to see the tooltip Mouse over this to see a different tooltip |

Hello!